RawKeyEvent

Struct RawKeyEvent 

pub struct RawKeyEvent {
    pub key: KeyCode,
    pub modifiers: Modifiers,
    pub leds: KeyboardLedStatus,
    pub phys_code: Option<PhysKeyCode>,
    pub raw_code: u32,
    pub repeat_count: u16,
    pub key_is_down: bool,
    pub handled: Handled,
}
A key event prior to any dead key or IME composition

Fields

key: KeyCodemodifiers: Modifiersleds: KeyboardLedStatusphys_code: Option<PhysKeyCode>

The physical location of the key on an ANSI-Standard US layout

raw_code: u32

The OS and hardware dependent key code for the key

repeat_count: u16

How many times this key repeats

key_is_down: bool

If true, this is a key down rather than a key up event

handled: Handled

Implementations

Source

impl RawKeyEvent

pub fn set_handled(&self)

Mark the event as handled, in order to prevent additional processing.